@@ -124,8 +124,10 @@ class APIClient:
 
         if 'token' not in wml_credentials and 'password' not in wml_credentials and 'apikey' not in wml_credentials:
             try:
-                self.wml_credentials['token'] = BaseDataConnection._get_token_from_environment()
-                wml_credentials['token'] = self.wml_credentials['token']
+                token = BaseDataConnection._get_token_from_environment()
+                if token:
+                    self.wml_credentials['token'] = token
+                    wml_credentials['token'] = self.wml_credentials['token']
             except Exception as e:
                 pass
 
