@@ -24,6 +24,7 @@ from pandas import DataFrame
 import ibm_watson_machine_learning._wrappers.requests as requests
 
 from ..experiment import AutoAI
+from ..utils import is_lale_pipeline
 from ..utils.autoai.utils import (prepare_auto_ai_model_to_publish, prepare_auto_ai_model_to_publish_normal_scenario,
                                   remove_file, prepare_auto_ai_model_to_publish_notebook,
                                   prepare_auto_ai_model_to_publish_notebook_normal_scenario,
@@ -205,13 +206,11 @@ class BaseDeployment(ABC):
                                "Please specify the AutoAI model name to deploy.")
                 print(warning_msg)
                 warn(warning_msg)
-            # note: check if model is of lale type, if yes, convert it back to scikit
-            try:
-                model = kwargs['model'].export_to_sklearn_pipeline()
 
-            except AttributeError:
+            if is_lale_pipeline(kwargs['model']):
+                model = kwargs['model'].export_to_sklearn_pipeline()
+            else:
                 model = kwargs['model']
-            # --- end note
 
             # note: check if model is of lale type, if yes, convert it back to scikit
             if not isinstance(kwargs['model'], str):
@@ -338,13 +337,11 @@ class BaseDeployment(ABC):
                                    "Please specify the AutoAI model name to deploy.")
                     print(warning_msg)
                     warn(warning_msg)
-                # note: check if model is of lale type, if yes, convert it back to scikit
-                try:
-                    model = kwargs['model'].export_to_sklearn_pipeline()
 
-                except AttributeError:
+                if is_lale_pipeline(kwargs['model']):
+                    model = kwargs['model'].export_to_sklearn_pipeline()
+                else:
                     model = kwargs['model']
-                # --- end note
 
                 if not isinstance(kwargs['model'], str):
                     model_props = {
