@@ -181,12 +181,12 @@ class Batch(BaseDeployment):
 
         Parameters
         ----------
-        payload: pandas.DataFrame or List[DataConnection], required
-            DataFrame with data to test the model or data storage connection details to inform where payload data is stored.
+        payload: pandas.DataFrame or List[DataConnection] or Dict, required
+            DataFrame that contains data to test the model or data storage connection details that inform the model where payload data is stored.
 
         output_data_reference: DataConnection, optional
              DataConnection to the output COS for storing predictions.
-             Required nly when DataConnections are as a payload.
+             Required only when DataConnections are used as a payload.
 
         transaction_id: str, optional
             Can be used to indicate under which id the records will be saved into payload table in IBM OpenScale.
@@ -200,7 +200,7 @@ class Batch(BaseDeployment):
 
         Example
         -------
-        >>> score_details = deployment.score(payload=test_data)
+        >>> score_details = batch_service.run_job(payload=test_data)
         >>> print(score_details['entity']['scoring'])
             {'input_data': [{'fields': ['sepal_length',
                           'sepal_width',
@@ -214,7 +214,10 @@ class Batch(BaseDeployment):
                             1.6405926235405522e-05]]]}]
         >>>
         >>> payload_reference = DataConnection(location=DSLocation(asset_id=asset_id))
-        >>> score_details = deployment.score(payload=payload_reference, output_data_filename = "scoring_output.csv")
+        >>> score_details = batch_service.run_job(payload=payload_reference, output_data_filename = "scoring_output.csv")
+        >>> score_details = batch_service.run_job(payload={'observations': payload_reference})
+        >>> score_details = batch_service.run_job(payload=[payload_reference])
+        >>> score_details = batch_service.run_job(payload={'observations': payload_reference, 'supporting_features': supporting_features_reference})  # supporting features time series forecasting sceanrio
         """
 
         if isinstance(payload, dict):
