@@ -495,7 +495,7 @@ class AutoAI(BaseExperiment):
             elif self._workspace.wml_client.ICP:
                 print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
             else:
-                print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
+                raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cloud"))
 
         if prediction_type == PredictionType.FORECASTING and self._workspace.wml_client.ICP and \
                 (self._workspace.wml_client.wml_credentials['version'].startswith('2.5') or \
