@@ -97,7 +97,6 @@ class WMLEngine(BaseEngine):
                             'drop_duplicates': self._auto_pipelines_parameters.get('drop_duplicates'),
                             'optimization': {
                                 'learning_type': 'timeseries' if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING else self._auto_pipelines_parameters.get('prediction_type'),
-                                'max_num_daub_ensembles': self._auto_pipelines_parameters.get('max_num_daub_ensembles'),
                                 'cognito_transform_names':
                                     self._auto_pipelines_parameters.get('cognito_transform_names'),
                                 'run_cognito_flag': True,
@@ -121,6 +120,11 @@ class WMLEngine(BaseEngine):
             }
         }
 
+        if self._auto_pipelines_parameters.get('max_num_daub_ensembles') is not None:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'max_num_daub_ensembles'] = self._auto_pipelines_parameters.get('max_num_daub_ensembles')
+
         if kwargs.get('enable_all_data_sources') is not None:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters']['enable_all_data_sources'
