@@ -76,8 +76,8 @@ class LocalAutoPipelines(BaseAutoPipelines):
     max_num_daub_ensembles: int, optional
         Maximum number (top-K ranked by DAUB model selection) of the selected algorithm, or estimator types,
         for example LGBMClassifierEstimator, XGBoostClassifierEstimator, or LogisticRegressionEstimator
-        to use in pipeline composition.  The default is 1, where only the highest ranked by model
-        selection algorithm type is used.
+        to use in pipeline composition. The default is None that means the true default value will be determined by the
+        internal different algorithms, where only the highest ranked by model selection algorithm type is used.
 
     train_sample_rows_test_size: float, optional
         Training data sampling percentage
@@ -106,7 +106,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
                  scoring: 'Metrics',
                  desc: str = None,
                  holdout_size: float = 0.1,
-                 max_num_daub_ensembles: int = 1,
+                 max_num_daub_ensembles: int = None,
                  train_sample_rows_test_size: float = 1.,
                  include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
                  cognito_transform_names: List['Transformers'] = None,
@@ -155,7 +155,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
                 'prediction_column': prediction_column,
                 'scoring': scoring,
                 'holdout_size': holdout_size,
-                'max_num_daub_ensembles': int(max_num_daub_ensembles),
+                'max_num_daub_ensembles': max_num_daub_ensembles,
                 'train_sample_rows_test_size': train_sample_rows_test_size,
                 'include_only_estimators': include_only_estimators,
                 'cognito_transform_names': cognito_transform_names,
@@ -675,11 +675,13 @@ class LocalAutoPipelines(BaseAutoPipelines):
             # TODO: expose this parameter to the user
             'compute_feature_importances_options': ['pipeline'],
             'compute_pipeline_notebooks_flag': False,
-            'max_num_daub_ensembles': self.params['max_num_daub_ensembles'],
             'scorer_for_ranking': self.params['scoring'],
             'cognito_transform_names': self.params.get('cognito_transform_names')
         }
 
+        if self.params['max_num_daub_ensembles'] is not None:
+            estimator_parameters['max_num_daub_ensembles'] = self.params['max_num_daub_ensembles']
+
         # note: only pass positive label when scoring is binary
         if self.params['positive_label'] and self.params['scoring'] == PredictionType.BINARY:
             estimator_parameters['positive_class'] = self.params['positive_label']
