@@ -362,7 +362,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             elif self._workspace.wml_client.ICP:
                 print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
             else:
-                print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
+                raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cloud"))
 
         if training_data_references is not None:
             training_data_reference = training_data_references
@@ -600,7 +600,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             elif self._workspace.wml_client.ICP:
                 print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
             else:
-                print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
+                raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cloud"))
 
         return self._engine.get_run_details(include_metrics=include_metrics)
 
