@@ -48,11 +48,11 @@ class Export(WMLResource):
            **Parameters**
 
            .. important::
-                #. **meta_props**:  meta data. To see available meta names use **client.export_assets.ConfigurationMetaNames.get()**\n
+                #. **meta_props**:  meta data. To see available meta names use **client.export_assets.ConfigurationMetaNames.get()\n
                    **type**: dict\n
-                #. **space_id**:  Space identifier**\n
+                #. **space_id**:  Space identifier\n
                    **type**: str\n
-                #. **project_id**:  Project identifier**\n
+                #. **project_id**:  Project identifier\n
                    **type**: str\n
 
            **Output**
@@ -233,9 +233,9 @@ class Export(WMLResource):
             .. important::
                 #. **export_id**:  Export job identifier\n
                    **type**: str\n
-                #. **space_id**:  Space identifier**\n
+                #. **space_id**:  Space identifier\n
                    **type**: str\n
-                #. **project_id**:  Project identifier**\n
+                #. **project_id**:  Project identifier\n
                    **type**: str\n
 
             **Output**
@@ -291,9 +291,9 @@ class Export(WMLResource):
            .. important::
                 #. **export_id**: export job identifier (optional)\n
                    **type**: str\n
-                #. **space_id**:  Space identifier**\n
+                #. **space_id**:  Space identifier\n
                    **type**: str\n
-                #. **project_id**:  Project identifier**\n
+                #. **project_id**:  Project identifier\n
                    **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
@@ -359,9 +359,9 @@ class Export(WMLResource):
            .. important::
                 #. **limit**:  limit number of fetched records\n
                    **type**: int\n
-                #. **space_id**:  Space identifier**\n
+                #. **space_id**:  Space identifier\n
                    **type**: str\n
-                #. **project_id**:  Project identifier**\n
+                #. **project_id**:  Project identifier\n
                    **type**: str\n
 
            **Output**
@@ -436,12 +436,12 @@ class Export(WMLResource):
             .. important::
                 #. **export_id**:  export job identifier\n
                    **type**: str\n
-                #. **space_id**:  Space identifier**\n
+                #. **space_id**:  Space identifier\n
                    **type**: str\n
-                #. **project_id**:  Project identifier**\n
+                #. **project_id**:  Project identifier\n
                    **type**: str\n
                 #. **file_path**:  name of local file to create. This should be absolute path of the file and
-                                  the file shouldn't exist**\n
+                                  the file shouldn't exist\n
                    **type**: str\n
 
 
