@@ -626,13 +626,12 @@ class DataConnection(BaseDataConnection):
         >>> data = train_connections[0].read() # only train data
         """
 
-        # enables flight automatically for CP4D 4.0.x, 4.5.x and cloud, for 3.0 and 3.5 we do not have a flight service there
+        # enables flight automatically for CP4D 4.0.x, 4.5.x, for 3.0 and 3.5 we do not have a flight service there
         try:
             use_flight = kwargs.get(
                 'use_flight',
                 bool((self._wml_client is not None or 'USER_ACCESS_TOKEN' in os.environ or 'RUNTIME_ENV_ACCESS_TOKEN_FILE' in os.environ) and (
-                        self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46 or
-                        self._wml_client.CLOUD_PLATFORM_SPACES)))
+                        self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46)))
         except:
             use_flight = False
 
@@ -972,12 +971,11 @@ class DataConnection(BaseDataConnection):
         remote_name: str, required
             Name that dataset should be stored with in remote data storage.
         """
-        # enables flight automatically for CP4D 4.0.x and cloud, for 3.0 and 3.5 we do not have a flight service there
+        # enables flight automatically for CP4D 4.0.x, for 3.0 and 3.5 we do not have a flight service there
         use_flight = kwargs.get(
             'use_flight',
             bool((self._wml_client is not None or 'USER_ACCESS_TOKEN' in os.environ or 'RUNTIME_ENV_ACCESS_TOKEN_FILE' in os.environ) and (
-                    self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46 or
-                    self._wml_client.CLOUD_PLATFORM_SPACES)))
+                    self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46)))
 
         flight_parameters = kwargs.get('flight_parameters', {})
 
