@@ -127,6 +127,8 @@ DATA_SOURCE_TYPE_BY_ID = u'{}/v2/datasource_types/{}'
 CONNECTION_ASSET = u'{}/v2/connections'
 CONNECTION_ASSET_SEARCH = u'{}/v2/connections'
 CONNECTION_BY_ID = u'{}/v2/connections/{}'
+CONNECTIONS_FILES = u'{}/v2/connections/files'
+CONNECTIONS_FILE = u'{}/v2/connections/files/{}'
 SOFTWARE_SPECIFICATION = u'{}/v2/software_specifications/{}'
 SOFTWARE_SPECIFICATIONS = u'{}/v2/software_specifications'
 HARDWARE_SPECIFICATION = u'{}/v2/hardware_specifications/{}'
@@ -434,6 +436,12 @@ class HrefDefinitions:
     def get_connection_by_id_href(self, connection_id):
         return CONNECTION_BY_ID.format(self._get_platform_url_if_exists(), connection_id)
 
+    def get_connections_files_href(self):
+        return CONNECTIONS_FILES.format(self._get_platform_url_if_exists())
+
+    def get_connections_file_href(self, file_name):
+        return CONNECTIONS_FILE.format(self._get_platform_url_if_exists(), file_name)
+
     def get_connection_data_types_href(self):
         return DATA_SOURCE_TYPE.format(self._get_platform_url_if_exists())
 
