@@ -531,3 +531,13 @@ class XGBClassifierLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
                                weights=self.sample_weight))
                 counts.append(len(self.y_train == k))
             return (np.array(average), np.array(counts))
+
+    def should_incr_n_completed_trains(self, payload):
+        """
+        Increment the number of completed executions of the TRAIN command at the party side
+
+        :param: payload: dict
+        """
+        return (payload['func'] == 'update_grad')
+
+
