@@ -678,14 +678,36 @@ class ModelCollection:
 
                     training_data_list.append(training_ref)
         else:
-            if artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA) and artifact.meta.prop(MetaNames.INPUT_DATA_SCHEMA) is None:
-                training_data_list=[]
+            if artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA):
+                if artifact.meta.prop(MetaNames.INPUT_DATA_SCHEMA) is None:
+                    input_schema_obj = artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA)
+                    if artifact.meta.prop(MetaNames.LABEL_FIELD):
+                        input_schema_obj['id'] = str(MetaNames.INPUT_DATA_SCHEMA)
+                        input_schema_obj['fields'] = [f for f in input_schema_obj['fields'] if
+                                                      f['name'] != artifact.meta.prop(MetaNames.LABEL_FIELD)]
+
+                    artifact.meta.add(MetaNames.INPUT_DATA_SCHEMA, input_schema_obj)
+
+                # note: issue #29958 set training schema in training_data_reference.schema to keep backward compatibility
+                training_data_list = []
                 training_data_ref_obj = artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA)
 
-                if artifact.meta.prop(MetaNames.LABEL_FIELD):
-                    training_data_ref_obj['fields'] = [f for f in training_data_ref_obj['fields'] if f['name'] != artifact.meta.prop(MetaNames.LABEL_FIELD)]
+                training_data_ref_obj["id"] = "1"
+                import os
+                if "DEPLOYMENT_PLATFORM" in os.environ and os.environ["DEPLOYMENT_PLATFORM"] == "private":
+                    type_ = "fs"
+                else:
+                    type_ = "container"
 
-                artifact.meta.set(MetaNames.INPUT_DATA_SCHEMA, training_data_ref_obj)
+                training_data_ref = {
+                    "id": "1",
+                    "type": type_,
+                    "location": {},
+                    "schema": training_data_ref_obj
+                }
+
+                training_data_list.append(training_data_ref)
+                # end note
 
         if artifact.meta.prop(MetaNames.SPACE_UID) is not None:
             spaceobj=artifact.meta.prop(MetaNames.SPACE_UID)
