@@ -157,13 +157,18 @@ class PkgExtn(WMLResource):
             if os.stat(file_path).st_size == 0:
                 raise WMLClientError('Package extension file cannot be empty')
 
-            if not self._ICP:
+            # chunking, when finally it will work on service side. to confirm it's working, the downloaded file needs to be the same as 400MB+ upladed file
+            #
+            # put_response = send_multipart_request(file_path,
+            #   (self._client.service_instance._wml_credentials['url'] if self._client.ICP else "") + pkg_extn_presigned_url)
+
+            href = (self._client.service_instance._wml_credentials['url'] if self._client.ICP else "") + pkg_extn_presigned_url
+
+            with open(file_path, 'rb') as f:
                 put_response = requests.put(
-                    pkg_extn_presigned_url,
-                    data=read_in_chunks()
+                    href,
+                    files={'file': (file_path, f.read(), 'application/octet-stream')}
                 )
-            else:
-                put_response = send_multipart_request(file_path, self._wml_credentials['url'] + pkg_extn_presigned_url)
 
             if put_response.status_code == 201 or put_response.status_code == 200:
                 # Step3: Mark the upload complete
