@@ -341,6 +341,9 @@ class Repository(WMLResource):
                     #. **round_number**: round number of a Federated Learning experiment that has been configured to save intermediate models.  This applies when model is a training id.  
                        **type**: int
 
+                    #. **experiment_metadata**: metadata retrieved from the experiment that created the model
+                        **type**: dict
+
                 **Output**
 
                 .. important::
@@ -396,17 +399,24 @@ class Repository(WMLResource):
                     >>>                                                               }]
                     >>>             }
 
-                    A way you might use me with local tar.gz containing model:\n
+                    store_model() method used with a local tar.gz file that contains a model:\n
 
                     >>> stored_model_details = client.repository.store_model(path_to_tar_gz, meta_props=metadata, training_data=None)
 
-                    A way you might use me with local directory containing model file(s):\n
+                    store_model() method used with a local directory that contains model files:\n
 
                     >>> stored_model_details = client.repository.store_model(path_to_model_directory, meta_props=metadata, training_data=None)
 
-                    A way you might use me with trained model guid:\n
+                    store_model() method used with the GUID of a trained model\n
 
                     >>> stored_model_details = client.repository.store_model(trained_model_guid, meta_props=metadata, training_data=None)
+
+                    store_model() method used with a pipeline that was generated by an experiment\n
+
+                    >>> metadata = {
+                    >>>        client.repository.ModelMetaNames.NAME: 'customer satisfaction prediction model'
+                    >>>}
+                    >>> stored_model_details = client.repository.store_model(pipeline_model, meta_props=metadata, experiment_metadata=experiment_metadata)
             """
 
         return self._client._models.store(model, meta_props=meta_props, training_data=training_data, training_target=training_target, pipeline=pipeline, feature_names=feature_names, label_column_names=label_column_names,subtrainingId=subtrainingId,round_number=round_number,experiment_metadata=experiment_metadata)
