@@ -19,6 +19,7 @@ from ibm_watson_machine_learning.metanames import ScriptMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure, ForbiddenActionForGitBasedProject
 import os
+import warnings
 
 _DEFAULT_LIST_LENGTH = 50
 
@@ -206,16 +207,26 @@ class Script(WMLResource):
             if lang == 'R':
                 if self._client.ICP_46:
                     rscript_sw_specs = ('runtime-22.2-r4.2',)
+                    deprecated_rscript_sw_specs = ('default_r3.6', 'runtime-22.1-r3.6',)
                 else:
                     rscript_sw_specs = ('default_r3.6', 'runtime-22.1-r3.6',)
+                    deprecated_rscript_sw_specs = ()
                 rscript_sw_spec_ids = [self._client.software_specifications.get_id_by_name(sw_name)
                                        for sw_name in rscript_sw_specs]
+                deprecated_sw_spec_ids = [self._client.software_specifications.get_id_by_name(sw_name)
+                                       for sw_name in deprecated_rscript_sw_specs]
 
-                if script_meta[u'software_spec_uid'] not in rscript_sw_spec_ids:
+                if script_meta[u'software_spec_uid'] not in rscript_sw_spec_ids + deprecated_sw_spec_ids:
                     raise WMLClientError(f"For R scripts, only base software specs {','.join(rscript_sw_specs)} "
                                          "are supported. Specify "
                                          "the id you get via "
                                          "self._client.software_specifications.get_id_by_name(sw_name)")
+                elif script_meta[u'software_spec_uid'] in deprecated_rscript_sw_specs:
+                    warnings.warn("Provided software spec is deprecated for R scripts. "
+                             f"Only base software specs {','.join(rscript_sw_specs)} "
+                             "are supported. Specify "
+                             "the id you get via "
+                             "self._client.software_specifications.get_id_by_name(sw_name)")
 
 
             if(sw_spec_details[u'entity'][u'software_specification'][u'type'] == 'base'):
