@@ -171,7 +171,7 @@ class Training(WMLResource):
                 elif self._client.ICP:
                     print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
                 else:
-                    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
+                    raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cloud"))
 
             return details
 
@@ -571,7 +571,8 @@ class Training(WMLResource):
             with StatusLogger(state) as status_logger:
                 while state not in ['error', 'completed', 'canceled', 'failed']:
                     time.sleep(5)
-                    state = self.get_status(trained_model_guid)['state']
+                    status = self.get_status(trained_model_guid)
+                    state = status['state']
                     status_logger.log_state(state)
 
             if u'completed' in state:
