@@ -381,10 +381,10 @@ class VisualizationTypes:
 
 class SamplingTypes:
     """Types of training data sampling"""
-    FIRST_N_RECORDS = 'first_n_records'
+    FIRST_VALUES = 'first_n_records'
     RANDOM = 'random'
     STRATIFIED = 'stratified'
-    TRUNCATE = 'truncate'
+    LAST_VALUES = 'truncate'
 
 
 class ImputationStrategy(Enum):
